#!/usr/bin/env python

#
# Copyright 2015, Olivier MATZ <zer0@droids-corp.org>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the University of California, Berkeley nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

#
# This is an example of how imapami can be extended in python. The
# following code creates a new condition class that is registered. The
# same can be done for actions.
#
# After that, the script calls imapami.run() which behaves like imapami
# with the new condition registered.
#

import imapami
import imapami.conditions

class ImapamiCondList(imapami.conditions.ImapamiCond):
    """
    Match if the sender is present in the file.

    The file is a list of mails, one per line.

    Arguments:
      file: <string> [mandatory]
        The path to the balcklist file.

    Example:
      list: {filename: /home/user/list.txt}
    """
    name = "list"

    def __init__(self, filename):
        ImapamiCond.__init__(self, fetch='headers')
        self.filename = filename

    def check(self, imapami_handler, msg_id, hdrs, body_part1, body_all):
        From = self.evaluate("{From}", imapami_handler, hdrs)
        try:
            f = open(self.filename)
            while True:
                l = f.readline()
                if l == '':
                    break
                if From.lower() == l[:-1].lower():
                    return True
        except IOError:
            imapami_handler.logger.warning("error opening list file <%s>")
        return False
imapami.conditions.register(ImapamiCondList)

if __name__ == '__main__':
    imapami.main()
